# -*- coding: utf-8 -*-
# @Author: root
# @Date:   2016-05-24 16:59:42
# @Last Modified by:   drinks
# @Last Modified time: 2016-05-24 23:09:56
__all__ = ('PY3', 'unicode')

import sys
PY3 = sys.version_info[0] > 2
if PY3:
    unicode = str
unicode = unicode



# -*- coding: utf-8 -*-
# @Author: root
# @Date:   2016-05-24 16:24:54
# @Last Modified by:   drinks
# @Last Modified time: 2016-06-02 23:52:45
from __future__ import print_function

from collections import OrderedDict
from colorfulprinter import PrettyPrinter
from colorfulprinter import color_write, npprint
try:
    from StringIO import StringIO
except ImportError:
    from io import StringIO
si = StringIO()
si.write = color_write(si.write)
pp = PrettyPrinter(indent=4, stream=si)
d = OrderedDict()
for i in range(15):
    d[i] = list(range(i))
d[3] = [u'中国', u'中国']
npprint(d)



# -*- coding: utf-8 -*-
# @Author: linlin
# @Date:   2016-05-24 16:21:07
# @Last Modified by:   drinks
# @Last Modified time: 2016-05-25 10:30:34
from __future__ import print_function
import os
from random import choice
__all__ = ('colored', 'cprint', 'color_write')
ATTRIBUTES = dict(zip(
    [
        'bold', 'dark', '', 'underline', 'blink', '', 'reverse', 'concealed'
    ], list(range(1, 9))))
del ATTRIBUTES['']

HIGHLIGHTS = dict(zip(
    [
        'on_grey', 'on_red', 'on_green', 'on_yellow', 'on_blue', 'on_magenta',
        'on_cyan', 'on_white'
    ], list(range(40, 48))))
COLORS = dict(zip(
    [
        'grey',
        'red',
        'green',
        'yellow',
        'blue',
        'magenta',
        'cyan',
        'white',
    ], list(range(30, 38))))
COLORS.pop('grey')
RESET = '\033[0m'


def colored(text, color=None, on_color=None, attrs=None):
    if os.getenv('ANSI_COLORS_DISABLED') is None:
        fmt_str = '\033[{0}m{1}'
        text = color is not None and fmt_str.format(COLORS[color],
                                                    text) or text
        text = on_color is not None and fmt_str.format(HIGHLIGHTS[on_color],
                                                       text) or text
        if attrs is not None:
            for attr in attrs:
                text = fmt_str.format(ATTRIBUTES[attr], text)
        text = ''.join([text, RESET])
    return text


def cprint(text, color=None, on_color=None, attrs=None, **kwargs):
    print(colored(text, color=color, on_color=on_color, attrs=attrs), **kwargs)


def color_write(func):
    def warp(text):
        color = choice(list(COLORS))
        text = func(colored(text, color=color))
        return text
    return warp



# -*- coding: utf-8 -*-
# @Author: root
# @Date:   2016-05-24 16:50:06
# @Last Modified by:   drinks
# @Last Modified time: 2016-06-03 10:15:55

from setuptools import setup, find_packages

VERSION = '0.4.8'

setup(name='colorfulprinter',
      version=VERSION,
      description="A drop in replacement for python built-in pprint package",
      long_description='just enjoy',
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'Topic :: Software Development',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.5',
      ],
      keywords='python pprint color console terminal unicode',
      author='drink',
      author_email='drinksober@foxmail.com',
      url='https://github.com/drinksober/colorfulprinter',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=True,
      install_requires=[],
      )
